/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as zowe from '@zowe/cli';
import { IRestApiResponse } from '../../doc/IRestApiResponse';
import { IUploadRseOptions } from './doc/IUploadRseOptions';
export declare class Upload {
    /**
     * Upload content from file to data set
     * @param {Session}         session      - z/OS connection info
     * @param {string}          inputFile    - path to a file
     * @param {string}          dataSetName  - Name of the data set to write to
     * @param {IUploadRseOptions}  [options={}] - Uploading options
     *
     * @return {Promise<IZosFilesResponse>} A response indicating the out come
     *
     * @throws {ImperativeError} When encounter error scenarios.
     *
     */
    static fileToDataset(session: zowe.imperative.Session, inputFile: string, dataSetName: string, profile: zowe.imperative.IProfile, options?: IUploadRseOptions, mappingsFile?: string): Promise<IRestApiResponse>;
    /**
     * Upload content from a directory to a PDS
     * @param {Session} session      - z/OS connection info
     * @param {string}          inputDir     - path to a file
     * @param {string}          dataSetName  - Name of the data set to write to
     * @param {IUploadRseOptions}  [options={}] - Uploading options
     *
     * @return {Promise<IZosFilesResponse>} A response indicating the out come
     *
     * @throws {ImperativeError} When encounter error scenarios.
     *
     */
    static dirToPds(session: zowe.imperative.Session, inputDir: string, dataSetName: string, profile: zowe.imperative.IProfile, options?: IUploadRseOptions, mappingsFile?: string): Promise<IRestApiResponse>;
    /**
     * Writting data buffer to a data set.
     * @param {Session} session      - z/OS connection info
     * @param {Buffer}          fileBuffer   - Data buffer to be written
     * @param {string}          dataSetName  - Name of the data set to write to
     * @param {IUploadRseOptions}  [options={}] - Uploading options
     *
     * @return {Promise<IZosFilesResponse>} A response indicating the out come
     *
     * @throws {ImperativeError} When encounter error scenarios.
     */
    static bufferToDataSet(session: zowe.imperative.Session, records: string, dataSetName: string, options?: IUploadRseOptions): Promise<IRestApiResponse>;
    /**
     * Upload content from input path to dataSet or PDS members
     * @param {Session} session      - z/OS connection info
     * @param {string}          inputPath    - User input path to file or directory
     * @param {string}          dataSetName  - Name of the data set to write to
     * @param {IUploadRseOptions}  [options={}] - Uploading options
     *
     * @param task - use this to be updated on the current status of the upload operation
     * @return {Promise<IZosFilesResponse>} A response indicating the out come
     *
     * @throws {ImperativeError} When encounter error scenarios.
     *
     * @example pathToDataSet(session, "file.txt", "ps.name")
     * @example pathToDataset(session, "file.txt", "psd.name(member)")
     * @example pathToDataSet(session, "directory", "pds.name")
     * @example pathToDataset(session, "/full/path/file.txt", "ps.name")
     *
     * Note:
     * This method does everything needed to do from checking if path is file or directory
     * and if data set is sequential file or PDS to determind what name to be used when
     * upload content to data set.  All you have to specify is a directory and a dsname.
     */
    static pathToDataSet(session: zowe.imperative.Session, inputPath: string, dataSetName: string, profile: zowe.imperative.IProfile, options?: IUploadRseOptions, mappingsFile?: string, isDir?: boolean): Promise<IRestApiResponse>;
    static fileToUSSFile(session: zowe.imperative.Session, inputFile: string, ussname: string, options: IUploadRseOptions): Promise<IRestApiResponse>;
    static tagUssFile(session: zowe.imperative.Session, ussname: string, encoding: string): Promise<void>;
    /**
     * Upload local directory to USS directory
     * @param {Session} session - z/OS connection info
     * @param {string} inputDirectory   - the path of local directory
     * @param {string} ussname          - the name of uss folder
     * @param {IUploadRseOptions} [options={}]   - Uploading options
     * @returns {Promise<IZosFilesResponse>}
     */
    static dirToUSSDir(session: zowe.imperative.Session, inputDirectory: string, ussname: string, options?: IUploadRseOptions): Promise<IRestApiResponse>;
    /**
     * Check if USS directory exists
     * @param {Session} session - z/OS connection info
     * @param {string} ussname          - the name of uss folder
     * @return {Promise<boolean>}
     */
    static isDataSetExist(session: zowe.imperative.Session, dataSetName: string, options?: zowe.IListOptions): Promise<boolean>;
    /**
     * Check if USS file exists
     * @param {Session} session - z/OS connection info
     * @param {string} ussname          - the name of uss folder
     * @return {Promise<boolean>}
     */
    static isFileExist(session: zowe.imperative.Session, ussname: string): Promise<boolean>;
    /**
     * Check if USS directory exists
     * @param {Session} session - z/OS connection info
     * @param {string} ussname          - the name of uss folder
     * @return {Promise<boolean>}
     */
    static isDirectoryExist(session: zowe.imperative.Session, ussname: string): Promise<boolean>;
    /**
     * Upload directory to USS recursively
     * @param {Session} session       - z/OS connection info
     * @param {string} inputDirectory         - the path of local directory
     * @param {string} ussname                - the name of uss folder
     * @param {IUploadRseOptions} [options={}]   - Uploading options
     * @return {null}
     */
    static dirToUSSDirRecursive(session: zowe.imperative.Session, inputDirectory: string, ussname: string, options?: IUploadRseOptions): Promise<IRestApiResponse>;
    private static uploadFile;
    private static uploadFileAndTagBasedOnAttributes;
    /**
     * Checks if a given directory has sub-directories or not
     * @param {string} dirPath full-path for the directory to check
     */
    private static hasDirs;
    /**
     * Returns an array of sub-directories objects, containing directory name, and full path specification
     * @param dirPath full-path for the directory to check
     */
    private static getDirs;
    /**
     * helper function to prepare file names for display on progress bar
     * @param stringInput string input to be formated
     */
    private static formatStringForDisplay;
    /**
     * Get Log
     * @returns {Logger} applicationLogger.
     */
    private static get log();
}
